@@ -11,7 +11,6 @@ from palp import settings
 from threading import Thread
 from abc import abstractmethod
 from quickdb import RedisLockNoWait
-from palp.buffer.buffer_item import ItemBuffer
 from palp.spider.spider_base import BaseSpider
 from palp.tool.client_heart import ClientHeart
 from requests.cookies import RequestsCookieJar
@@ -29,20 +28,10 @@ class DistributiveSpider(BaseSpider, Thread):
         setattr(settings, 'SPIDER_TYPE', 2)
         self.redis_key = redis_key or self.name
 
-        # 根据 spider 的名字设置前缀
-        setattr(settings, 'REDIS_KEY_QUEUE_ITEM', settings.REDIS_KEY_QUEUE_ITEM.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_MASTER', settings.REDIS_KEY_MASTER.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_STOP', settings.REDIS_KEY_STOP.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_LOCK', settings.REDIS_KEY_LOCK.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_HEARTBEAT', settings.REDIS_KEY_HEARTBEAT.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_QUEUE_REQUEST', settings.REDIS_KEY_QUEUE_REQUEST.format(redis_key=self.redis_key))
-
-        setattr(settings, 'REDIS_KEY_HEARTBEAT_FAILED',
-                settings.REDIS_KEY_HEARTBEAT_FAILED.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_QUEUE_FILTER_REQUEST',
-                settings.REDIS_KEY_QUEUE_FILTER_REQUEST.format(redis_key=self.redis_key))
-        setattr(settings, 'REDIS_KEY_QUEUE_FILTER_ITEM',
-                settings.REDIS_KEY_QUEUE_FILTER_ITEM.format(redis_key=self.redis_key))
+        # 根据 spider 的名字设置 redis 前缀
+        for key, value in settings.__dict__.items():
+            if key.startswith('REDIS_KEY'):
+                setattr(settings, key, value.format(redis_key=self.redis_key))
 
         super().__init__(thread_count, request_filter, item_filter)
 
